# PYostal: Postal API Client

This library helps you use the [Postal](https://github.com/atech/postal) API in Python 3.9 (and above) to send Emails, get Message Details & Deliveries and Implement Events to handle Server Webhooks.

It uses [Requests](https://github.com/psf/requests) the simple, yet elegant HTTP library to handle all the http sorcery.

## Installing Requests and Supported Versions

PYostal is available on PyPI:

```bash
$ python -m pip install pyostal
```
PYostal officially supports Python 3.9+.

## API Information

You can get more information about the Postal API and Payloads in the [Postal Project Wiki](https://github.com/postalhq/postal/wiki/Using-the-API)

## Author

Rafael Nevarez
